Contacts class
Constructors
- Contacts({void onChange()?, void onCreate(ContactEvent contactEvent)?, void onUpdate(ContactEvent contactEvent)?, void onDelete(ContactEvent contactEvent)?})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
localCopy
→ Map<
String, Contact> -
no setter
- localCopyExists → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setOnChange ← dynamic Function()?
-
no getter
- setOnCreate ← ContactsAction?
-
no getter
- setOnDelete ← ContactsAction?
-
no getter
- setOnUpdate ← ContactsAction?
-
no getter
-
streamController
↔ BehaviorSubject<
ContactEvent> -
getter/setter pair
Methods
-
compare(
) → void -
dispose(
) → void -
hasChanged(
) → void -
init(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readContacts(
) → Future< List< Contact> > -
toString(
) → String -
A string representation of this object.
inherited
-
updateLocalCopy(
{List< Contact> ? latestContacts}) → FutureOr<void> -
writeContacts(
) → List
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited